@@ -4,18 +4,19 @@ from django.forms import (
     FloatField,
 )
 
+from dcim.models import Platform
 from netbox.forms import (
     NetBoxModelBulkEditForm,
     NetBoxModelFilterSetForm,
     NetBoxModelImportForm,
     NetBoxModelForm,
 )
-from netbox_storage.models import Drive
+from netbox_storage.models import Drive, StorageConfigurationDrive
 from utilities.forms import (
     CSVModelChoiceField,
     DynamicModelChoiceField,
 )
-from virtualization.models import Cluster, ClusterType
+from virtualization.models import Cluster, ClusterType, VirtualMachine
 
 
 class DriveForm(NetBoxModelForm):
@@ -43,21 +44,48 @@ class DriveForm(NetBoxModelForm):
         help_text="Short Description e.g. Hard Drive 1 on SSD Cluster",
     )
 
-    fieldsets = (
-        (
-            "Drive Cluster Config",
-            (
-                "cluster_type",
-                "cluster",
-            ),
-        ),
-        (
-            "Drive Configuration",
-            (
-                "size",
-                "description",
-            ),
-        ),
+    class Meta:
+        model = Drive
+
+        fields = (
+            "size",
+            "cluster",
+            "description",
+        )
+
+
+class DriveCreateForm(NetBoxModelForm):
+    size = FloatField(
+        label="Size (GB)",
+        help_text="The size of the drive e.g. 25",
+        validators=[MinValueValidator(1)],
+    )
+    cluster_type = DynamicModelChoiceField(
+        queryset=ClusterType.objects.all(),
+        help_text="The Cluster Type of the drive",
+    )
+    cluster = DynamicModelChoiceField(
+        queryset=Cluster.objects.all(),
+        query_params={
+            'type_id': '$cluster_type'  # ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
+        },
+        help_text="The Storage Cluster of the drive",
+    )
+    description = CharField(
+        required=False,
+        label="Description",
+        help_text="Short Description e.g. Hard Drive 1 on SSD Cluster",
+    )
+
+    virtual_machine = DynamicModelChoiceField(
+        label="Virtual Machine",
+        queryset=VirtualMachine.objects.all(),
+        help_text="Mapping between drive and virtual machine  e.g. vm-testinstall-01",
+    )
+    platform = DynamicModelChoiceField(
+        label="Platform",
+        queryset=Platform.objects.all(),
+        help_text="Mapping between drive and platform  e.g. Rocky Linux 9",
     )
 
     class Meta:
@@ -69,6 +97,12 @@ class DriveForm(NetBoxModelForm):
             "description",
         )
 
+    def save(self, *args, **kwargs):
+        print("Hello")
+        drive = super().save(*args, **kwargs)
+        StorageConfigurationDrive.objects.create(virtual_machine=self.cleaned_data['virtual_machine'], drive=drive)
+        return drive
+
 
 class DriveFilterForm(NetBoxModelFilterSetForm):
     """Form for filtering Drive instances."""
