@@ -129,33 +129,34 @@ class Partition(NetBoxModel):
         on_delete=models.CASCADE,
         related_name='drive_partition',
     )
-    device = models.ForeignKey(
-        LinuxDevice,
-        on_delete=models.CASCADE,
-        related_name='device_partition',
-    )
     size = models.FloatField(
         verbose_name='Size (GB)'
     )
-    type = models.CharField(
-        max_length=255,
+    fs_type = models.ForeignKey(
+        Filesystem,
+        on_delete=models.CASCADE,
+        related_name='fs_partition',
+        verbose_name='Filesystem',
+    )
+    letter = models.CharField(
+        max_length=1,
     )
     description = models.CharField(
         max_length=255,
         blank=True,
     )
 
-    clone_fields = ['drive', 'device', 'size', 'type', 'description']
+    clone_fields = ['drive', 'size', 'fs_type', 'letter', 'description']
 
     prerequisite_models = (
         'netbox_storage.Drive',
     )
 
     class Meta:
-        ordering = ['size']
+        ordering = ['drive', 'size', 'fs_type', 'letter', 'description']
 
     def __str__(self):
-        return f'{self.device}'
+        return f'{self.letter}'
 
     def get_absolute_url(self):
         return reverse('plugins:netbox_storage:partition', kwargs={'pk': self.pk})
