@@ -1,3 +1,5 @@
+import django_tables2 as tables
+
 from netbox.tables import (
     NetBoxTable,
     ToggleColumn,
@@ -10,6 +12,9 @@ class VolumeGroupTable(NetBoxTable):
     """Table for displaying VolumeGroup objects."""
 
     pk = ToggleColumn()
+    vg_name = tables.Column(
+        linkify=True
+    )
 
     class Meta(NetBoxTable.Meta):
         model = VolumeGroup
