@@ -5,25 +5,24 @@ from netbox_storage.models import LogicalVolume, StorageConfigurationDrive, \
     TemplateConfigurationDrive, Drive, Partition, LinuxDevice, MountedVolume
 
 
-class RelatedDrives(PluginTemplateExtension):
+class VMTemplateContent(PluginTemplateExtension):
     model = "virtualization.virtualmachine"
 
     def left_page(self):
         obj = self.context.get("object")
 
-        lv = LogicalVolume.objects.all()
-
         storage_configuration = StorageConfigurationDrive.objects.filter(virtual_machine=obj)
+        partitions = []
+        for sc in storage_configuration:
+            partitions += list(Partition.objects.filter(drive=sc.drive))
 
         platform = obj.platform
         if platform is not None:
             if platform.name.lower().__contains__('windows'):
                 return self.render(
-                    "netbox_storage/inc/windowsvolume_box.html",
+                    "netbox_storage/inc/vm_windows_box.html",
                     extra_context={
-                        # "volumes": volumes,
-                        # "unmapped_drives": unmapped_drives,
-                        "type": type(obj.platform),
+                        "partitions": partitions,
                     },
                 )
             elif platform.name.lower().__contains__('linux'):
@@ -32,15 +31,11 @@ class RelatedDrives(PluginTemplateExtension):
                 )
         else:
             return self.render(
-                "netbox_storage/inc/unknown_os_box.html",
-                extra_context={
-                    "lv": lv,
-                    "storage_configuration": storage_configuration
-                }
+                "netbox_storage/inc/unknown_os_box.html"
             )
 
 
-class TemplateVolumeConfig(PluginTemplateExtension):
+class PlatformTemplateContent(PluginTemplateExtension):
     model = "dcim.platform"
 
     def right_page(self):
@@ -110,4 +105,4 @@ class TemplateVolumeConfig(PluginTemplateExtension):
         )
 
 
-template_extensions = [RelatedDrives, TemplateVolumeConfig]
+template_extensions = [VMTemplateContent, PlatformTemplateContent]
