@@ -1,14 +1,14 @@
 from netbox.views import generic
 
-from netbox_storage.filters import DriveFilter, PartitionFilter, PhysicalVolumeFilter
+from netbox_storage.filters import DriveFilter, PartitionFilter
 from netbox_storage.forms import (
     DriveImportForm,
     DriveFilterForm,
     DriveForm,
-    DriveBulkEditForm
+    DriveBulkEditForm, DriveCreateForm
 )
-from netbox_storage.models import Drive, Partition, PhysicalVolume
-from netbox_storage.tables import DriveTable, PartitionTable, PhysicalVolumeTable
+from netbox_storage.models import Drive, Partition
+from netbox_storage.tables import DriveTable, PartitionTable
 from utilities.views import ViewTab, register_model_view
 
 
@@ -25,9 +25,13 @@ class DriveView(generic.ObjectView):
     queryset = Drive.objects.all()
 
 
-class DriveEditView(generic.ObjectEditView):
-    """View for editing a Drive instance."""
+class DriveAddView(generic.ObjectEditView):
+    queryset = Drive.objects.all()
+    form = DriveCreateForm
+    template_name = 'netbox_storage/drive_create.html'
 
+
+class DriveEditView(generic.ObjectEditView):
     queryset = Drive.objects.all()
     form = DriveForm
     default_return_url = "plugins:netbox_storage:drive_list"
@@ -76,24 +80,3 @@ class DrivePartitionListView(generic.ObjectChildrenView):
         return Partition.objects.filter(
             drive=parent
         )
-
-
-@register_model_view(Drive, "physicalvolumes")
-class DrivePhysicalVolumeListView(generic.ObjectChildrenView):
-    queryset = Drive.objects.all()
-    child_model = PhysicalVolume
-    table = PhysicalVolumeTable
-    filterset = PhysicalVolumeFilter
-    template_name = "netbox_storage/drive/physicalvolume.html"
-    hide_if_empty = True
-
-    tab = ViewTab(
-        label="Physical Volumes",
-        badge=lambda obj: obj.physicalvolumes_count(),
-        hide_if_empty=True,
-    )
-
-    def get_children(self, request, parent):
-        return PhysicalVolume.objects.filter(
-            drive=parent
-        )
